@@ -55,8 +55,6 @@ import java.lang.reflect.Field;
 import java.net.InetSocketAddress;
 import java.net.SocketTimeoutException;
 import java.nio.charset.UnsupportedCharsetException;
-import java.security.PrivilegedActionException;
-import java.security.PrivilegedExceptionAction;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.Locale;
@@ -69,6 +67,7 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
+import javax.mail.Provider;
 import javax.mail.event.FolderEvent;
 import javax.mail.event.FolderListener;
 import javax.mail.internet.idn.IDNA;
@@ -90,7 +89,7 @@ import com.openexchange.imap.entity2acl.Entity2ACLInit;
 import com.openexchange.imap.notify.internal.IMAPNotifierMessageRecentListener;
 import com.openexchange.imap.notify.internal.IMAPNotifierRegistry;
 import com.openexchange.imap.ping.IMAPCapabilityAndGreetingCache;
-import com.openexchange.imap.services.IMAPServiceRegistry;
+import com.openexchange.imap.services.Services;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.StringAllocator;
 import com.openexchange.log.Log;
@@ -115,6 +114,7 @@ import com.openexchange.timer.TimerService;
 import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.IMAPStore;
+import com.sun.mail.imap.JavaIMAPStore;
 
 /**
  * {@link IMAPAccess} - Establishes an IMAP access and provides access to storages.
@@ -156,30 +156,6 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     private static final String KERBEROS_SESSION_SUBJECT = "kerberosSubject";
 
-    private static final class SaslImapLoginAction implements PrivilegedExceptionAction<Object> {
-
-        private final IMAPStore is;
-        private final String server;
-        private final int port;
-        private final String login;
-        private final String pw;
-
-        protected SaslImapLoginAction(final IMAPStore is,final String server, final int port, final String login, final String pw) {
-            super();
-            this.is = is;
-            this.server = server;
-            this.port = port;
-            this.login = login;
-            this.pw = pw;
-        }
-
-        @Override
-        public Object run() throws MessagingException {
-            is.connect(server, port, login, pw);
-            return null;
-        }
-    }
-
     private static final class Key {
         final int contextId;
         final int userId;
@@ -225,7 +201,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             synchronized (IMAPAccess.class) {
                 tmp = validityDisabled;
                 if (null == tmp) {
-                    final ConfigurationService service = IMAPServiceRegistry.getServiceRegistry().getService(ConfigurationService.class);
+                    final ConfigurationService service = Services.getService(ConfigurationService.class);
                     tmp = Boolean.valueOf(service != null && service.getBoolProperty("com.openexchange.imap.validityDisabled", false));
                     validityDisabled = tmp;
                 }
@@ -508,23 +484,6 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         return MailAccount.DEFAULT_ID == accountId && null != kerberosSubject;
     }
 
-    private static void handlePrivilegedActionException(final PrivilegedActionException e) throws MessagingException, OXException {
-        if (null == e) {
-            return;
-        }
-        final Exception cause = e.getException();
-        if (null == cause) {
-            throw MailExceptionCode.UNEXPECTED_ERROR.create(e.getCause(), e.getMessage());
-        }
-        if (cause instanceof MessagingException) {
-            throw (MessagingException) cause;
-        }
-        if (cause instanceof OXException) {
-            throw (OXException) cause;
-        }
-        throw MailExceptionCode.UNEXPECTED_ERROR.create(cause.getCause(), cause.getMessage());
-    }
-
     private void reset() {
         super.resetFields();
         folderStorage = null;
@@ -840,7 +799,12 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             if (kerberosAuth || isProxyAuth) {
                 imapProps.put("mail.imap.sasl.enable", "true");
                 imapProps.put("mail.imap.sasl.authorizationid", user);
-                imapProps.put("mail.imap.sasl.mechanisms", (kerberosAuth ? "GSSAPI" : "PLAIN"));
+                if (kerberosAuth) {
+                    imapProps.put("mail.imap.sasl.mechanisms", "GSSAPI");
+                    imapProps.put("mail.imap.sasl.kerberosSubject", kerberosSubject);
+                } else {
+                    imapProps.put("mail.imap.sasl.mechanisms", "PLAIN");
+                }
             }
             /*
              * Get parameterized IMAP session
@@ -868,7 +832,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 }
             } else if (DEBUG && MailAccount.DEFAULT_ID == accountId) {
                 LOG.debug(new com.openexchange.java.StringAllocator(256).append("\n\n\tPropagating client IP address disabled on Open-Xchange server \"").append(
-                    IMAPServiceRegistry.getService(ConfigurationService.class).getProperty("AJP_JVM_ROUTE")).append("\"\n").toString());
+                    Services.getService(ConfigurationService.class).getProperty("com.openexchange.server.backendRoute")).append("\"\n").toString());
             }
             /*
              * Get connected store
@@ -977,7 +941,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             return true;
         }
 
-        final MailAccountStorageService storageService = IMAPServiceRegistry.getService(MailAccountStorageService.class);
+        final MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
         if (null == storageService) {
             return false;
         }
@@ -1048,15 +1012,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          * ... and connect it
          */
         try {
-            if (isKerberosAuth()) {
-                try {
-                    Subject.doAs(kerberosSubject, new SaslImapLoginAction(imapStore, server, port, login, pw));
-                } catch (final PrivilegedActionException e) {
-                    handlePrivilegedActionException(e);
-                }
-            } else {
-                imapStore.connect(server, port, login, pw);
-            }
+            imapStore.connect(server, port, login, pw);
         } catch (final AuthenticationFailedException e) {
             /*
              * Retry connect with AUTH=PLAIN disabled
@@ -1180,7 +1136,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         Entity2ACLInit.getInstance().start();
         maxCountCache = new NonBlockingHashMap<String, Integer>(16);
 
-        final ConfigurationService confService = IMAPServiceRegistry.getService(ConfigurationService.class);
+        final ConfigurationService confService = Services.getService(ConfigurationService.class);
         final boolean useIMAPStoreCache = null == confService ? true : confService.getBoolProperty("com.openexchange.imap.useIMAPStoreCache", true);
         USE_IMAP_STORE_CACHE.set(useIMAPStoreCache);
         long failedAuthTimeout;
@@ -1239,7 +1195,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             aclCapableServers = new NonBlockingHashMap<String, Boolean>();
         }
         if (null == cleanUpTimerTask) {
-            final TimerService timerService = IMAPServiceRegistry.getService(TimerService.class);
+            final TimerService timerService = Services.getService(TimerService.class);
             if (null != timerService) {
                 final Map<HostAndPort, Long> map1 = timedOutServers;
                 final Runnable r = new Runnable() {
@@ -1381,11 +1337,15 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     @Override
     protected IMailProperties createNewMailProperties() throws OXException {
-        final MailAccountStorageService storageService = IMAPServiceRegistry.getService(MailAccountStorageService.class, true);
+        final MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
         return new MailAccountIMAPProperties(storageService.getMailAccount(accountId, session.getUserId(), session.getContextId()));
     }
 
     private static javax.mail.Session setConnectProperties(final IMAPConfig config, final int timeout, final int connectionTimeout, final Properties imapProps) {
+        /*
+         * Custom IMAP store
+         */
+        imapProps.put("mail.imap.class", JavaIMAPStore.class.getName());
         /*
          * Set timeouts
          */
@@ -1456,7 +1416,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         /*
          * Create new IMAP session from initialized properties
          */
-        return javax.mail.Session.getInstance(imapProps, null);
+        final javax.mail.Session imapSession = javax.mail.Session.getInstance(imapProps, null);
+        imapSession.addProvider(new Provider(Provider.Type.STORE, "imap", JavaIMAPStore.class.getName(), "Open-Xchange, Inc.", "7.2.2"));
+        return imapSession;
     }
 
     @Override
